<?php
// Abstrakte Klasse Buch enthlt die allgemeinen Merkmale
// von Produkten, kann aber selbst sinnvoll nicht instanziiert werden
abstract class Produkt implements Kaufbar {
  // Konkrete Eigenschaften
  protected $nr;
  protected $name;
  protected $nettoPreis;
  protected $steuerSatz;
  // Konkreter Konstruktor
  public function __construct($nr, $name, $nettoPreis, $steuerSatz){
    $this->setNr($nr);
    $this->setName($name);
    if (is_double($nettoPreis)){
      $this->setNettoPreis($nettoPreis);
    }
    if (is_double($steuerSatz) && $steuerSatz <= 1){
      $this->setSteuerSatz($steuerSatz);
    }                        
  }
  //Konkrete Getter und Setter
  public function getNr(){
    return $this->nr;
  }
  public function setNr($nr){
    $this->nr = $nr;
  } 
  public function getName(){
    return $this->name;
  }
  public function setName($name){
    $this->name = $name;
  }
  public function getNettoPreis(){
    return $this->nettoPreis;
  }
  public function setNettoPreis($nettoPreis){
    $this->nettoPreis = $nettoPreis;
  }
  public function getSteuerSatz(){
    return $this->steuerSatz;
  }
  public function setSteuerSatz($steuerSatz){
    $this->steuerSatz = $steuerSatz;
  }
  public function getBruttoPreis(){
    return round($this->getNettoPreis() * (1+$this->getSteuerSatz()),2); ;
  }
  // Abstrakte Methode
  abstract public function getBeschreibung();            
}

// CD erweitert Produkt um die Verwaltung von Minuten 
class CD extends Produkt {
  // Zustzliche Eigenschaft
  private $minuten;
  // berschriebener Konstruktor
  public function __construct($nr, $name, $nettoPreis, $steuerSatz, $minuten){
    parent::__construct($nr, $name, $nettoPreis, $steuerSatz);
    $this->setMinuten($minuten);    
  }
  // Zustzliche Getter und Setter
  public function getMinuten(){
    return $this->minuten;
  }
  public function setMinuten($minuten){
    $this->minuten = $minuten;
  }
  // Implementierte konkrete Methode
  public function getBeschreibung(){
    return $this->getName()
           ." ("
           .$this->getMinuten()
           ."mins)";  
  }              
}

// Buch erweitert Produkt um die Verwaltung von Seiten 
class Buch extends Produkt {
  // Zustzliche Eigenschaft    
  private $seiten;
  // berschriebener Konstruktor
  public function __construct($nr, $name, $nettoPreis, $steuerSatz, $seiten){
    parent::__construct($nr, $name, $nettoPreis, $steuerSatz);
    $this->setSeiten($seiten);    
  }  
  // Zustzliche Getter und Setter  
  public function getSeiten(){
    return $this->steuerSatz;
  }
  public function setSeiten($seiten){
    $this->seiten = $seiten;
  }
  // Implementierte konkrete Methode
  public function getBeschreibung(){
    return $this->getName()
           ." ("
           .$this->getSeiten()
           ." Seiten)";  
  }       
}
?>
