<?php
//////////////////////////////////////////////
// Untersuchung von Klassen
//////////////////////////////////////////////
class ClassReflector {
 // Eigenschaften
 private $klasse;
 private $funktion;
 private $methode;
 private $eigenschaft;
 private $ausnahme;

 // Getter-/Setter-Methoden
 public function getKlasse(){
   return $this->klasse;	
 }
 public function setKlasse($klasse){
   if (class_exists($klasse)){
     $this->klasse = $klasse;	
   }	
 }
 public function getFunktion(){
   return $this->funktion;	
 }
 public function setFunktion($funktion){
     $this->funktion = $funktion;		
 }
 public function getMethode(){
   return $this->methode;	
 }
 public function setMethode($methode){
     $this->methode = $methode;		
 }
 public function getEigenschaft(){
   return $this->eigenschaft;	
 }
 public function setEigenschaft($eigenschaft){
     $this->eigenschaft = $eigenschaft;		
 }
 public function getAusnahme(){
   return $this->ausnahme;	
 }
 public function setAusnahme($ausnahme){
     $this->ausnahme = $ausnahme;		
 }       
 // Klassen untersuchen
 public function dokKlasseStandard(){
   if (class_exists($this->klasse)){
     $reflector = new ReflectionClass($this->klasse);
     return $reflector->export($this->klasse);
   }
 }
 
 // Funktion untersuchen
 public function dokFunktion(){
   $text = array();
   if (function_exists($this->funktion)){
     $funktion= new ReflectionFunction($this->funktion);
     $text["type"] = $funktion->isInternal() ? 'internal' : 'user-defined';
     $text["name"] = $funktion->getName();
     $text["file"] = $funktion->getFileName();
     $text["startLine"] = $funktion->getStartLine();
     $text["endLine"] = $funktion->getEndline();
     $text["doc"] = var_export($funktion->getDocComment(), 1);
     if ($statischeMitglieder = $funktion->getStaticVariables()){
       $text["statics"] = var_export($statischeMitglieder, 1);
     }
     if ($parameter = $funktion->getParameters()){
       $text["parameters"] = $parameter;
     }
   }
   return $text;
 }
 
 // Parameter untersuchen
 public function dokParameter(){
   $text = array();
   if (function_exists($this->funktion)){
     $funktion= new ReflectionFunction($this->funktion);
     foreach ($funktion->getParameters()
                                as $i => $parameter){
       $text[$i]["func"]  = $funktion->getName();
       $text[$i]["name"]  = var_export
                           ($parameter->getName(), 1);
       $text[$i]["class"] = var_export
                          ($parameter->getClass(), 1);
       $text[$i]["null"]  = var_export
                        ($parameter->allowsNull(), 1);
       $text[$i]["ref"]   = var_export
               ($parameter->isPassedByReference(), 1);
    }    
   }
   return $text;
 }
 
 // Klassen untersuchen
 public function dokKlasse(){
   $text = array();
   if (class_exists($this->klasse)){
     $klasse = new ReflectionClass($this->klasse);
     $text["internal"] =
     $klasse->isInternal() ? 'internal' : 'user-defined';
     $text["abstract"] =
     $klasse->isAbstract() ? ' abstract' : 'notAbstract';
     $text["final"] =
            $klasse->isFinal() ? ' final' : 'notFinal';
     $text["isInterface"] =
     $klasse->isInterface() ? 'isInterface' : 'isClass';
     $text["name"] = $klasse->getName();
     $text["parent"] =
              var_export($klasse->getParentClass(), 1);
     $text["file"] = $klasse->getFileName();
     $text["startLine"] = $klasse->getStartLine();
     $text["endLine"] = $klasse->getEndline();
     $text["modifiers"] = $klasse->getModifiers();
     $text["doc"] = var_export($klasse->getDocComment(), 1);
     $text["interfaces"] =
               var_export($klasse->getInterfaces(), 1);
     $text["constants"] =
                var_export($klasse->getConstants(), 1);
     $text["properties"] =
               var_export($klasse->getProperties(), 1);
     $text["methods"] =
                  var_export($klasse->getMethods(), 1);
     $text["instantiable"] = $klasse->isInstantiable() ? 'instantiable' : 'notInstantiable';
   }
   return $text;
 }
 
 // Methoden untersuchen
 public function dokMethode(){
   $text = array();
   if (class_exists($this->klasse)
       && in_array($this->methode,
                   get_class_methods($this->klasse))){
    $methode= new ReflectionMethod($this->klasse,
                                   $this->methode);
     
     $text["internal"] = $methode->isInternal()
                        ? 'internal' : 'user-defined';
     $text["abstract"] = $methode->isAbstract()
                        ? ' abstract' : 'notAbstract';
     $text["final"] =  $methode->isFinal()
                              ? ' final' : 'notFinal';
     $text["public"] = $methode->isPublic()
                            ? ' public' : 'notPublic';
     $text["private"] = $methode->isPrivate()
                          ? ' private' : 'notPrivate';
     $text["protected"] = $methode->isProtected()
                      ? ' protected' : 'notProtected';
     $text["static"] = $methode->isStatic()
                            ? ' static' : 'notStatic';
     $text["name"] = $methode->getName();
     $text["constructor"] = $methode->isConstructor()
                    ? 'constructor' : 'regularMethod';
     $text["file"] = $methode->getFileName();
     $text["startLine"] = $methode->getStartLine();
     $text["endLine"] = $methode->getEndline();
     $text["modifiers"] = $methode->getModifiers();
    $text["doc"] = var_export(
                         $methode->getDocComment(), 1);
    if ($statischeMitglieder= $methode->getStaticVariables()){
      $text["statics"] =  var_export($statischeMitglieder, 1);
    }
   }
   return $text;
 }
 
 // Eigenschaften untersuchen
 public function dokEigenschaft(){
   $text = array(); 	
   if (class_exists($this->klasse)
       || in_array($this->eigenschaft,
                   get_class_privates($this->klasse))){
     $eigenschaft= new ReflectionProperty
                      ($this->klasse, $this->eigenschaft);

     $text["public"] = $eigenschaft->isPublic()
                            ? ' public' : 'notPublic';
     $text["private"] = $eigenschaft->isPrivate()
                          ? ' private' : 'notPrivate';
     $text["protected"] = $eigenschaft->isProtected()
                      ? ' protected' : 'notProtected';
     $text["static"] = $eigenschaft->isStatic()
                            ? ' static' : 'notStatic';
     $text["name"] = $eigenschaft->getName();
     $text["default"] = $eigenschaft->isDefault()
                        ? 'compile-time' : 'run-time';
   }
   return $text;
 }
 
 // Ausnahmen untersuchen
 public function dokAusnahme(){
   $text = array(); 	
   if (class_exists($this->ausnahme)
       || in_array($this->ausnahme,
                   get_loaded_extensions())){                   	
     $ausnahme = new ReflectionExtension($this->ausnahme);
     $text["consts"] = $ausnahme->getConstants();
     $text["ini"] = $ausnahme->getINIEntries();
     $text["klassen"] = $ausnahme->getClassNames();
     $text["version"] = $ausnahme->getVersion();
     $text["name"] = $ausnahme->getName();
     $text["func"] = $ausnahme->getFunctions();
   }
   return $text;
 } 
}

?>
