<!doctype html public "-//W3C//DTD HTML 4.0 //EN">
<html>
<head>
       <title>Adapter</title>
</head>
<body>
<?php
// Erwartete Schnittstelle
interface Bezahlbar {
   public function zahlen();
   public function setBetrag($betrag);
   public function setEmpfaenger($empfaenger);   
   public function getBetrag();
   public function getEmpfaenger();      
}
// Direkte Implementierung der Schnittstelle
class Kreditkarte implements Bezahlbar {
   private $betrag;
   private $empfaenger;
   
   public function __construct($betrag, $empfaenger){
     $this->setBetrag($betrag);
     $this->setEmpfaenger($empfaenger);    
   } 
    
   public function zahlen(){
     return "Betrag ".$this->getBetrag()
            ." wird mit Kreditkarte an "
            .$this->getEmpfaenger()
            ." bezahlt.";  
   }
   public function setBetrag($betrag){
     $this->betrag = $betrag;   
   }
   public function setEmpfaenger($empfaenger){
     $this->empfaenger = $empfaenger;    
   } 
   public function getBetrag(){
     return $this->betrag;  
   }
   public function getEmpfaenger(){
     return $this->empfaenger;  
   }
}

// Zur Schnittstelle nicht passende Klasse
class Paypal {
   private $email;
   private $summe;
   public function __construct($summe, $email){
      $this->setSumme($summe);
      $this->setEmail($email);   
   }
   public function setEmail($email){
     $this->email = $email;    
   }
   public function getEmail(){
     return $this->email;  
   }
   public function setSumme($summe){
     $this->summe = $summe;    
   }
   public function getSumme(){
     return $this->summe;    
   }   
   public function bezahlen(){
     return "Summe ".$this->getSumme()
            ." wird mit Paypal an "
            .$this->getEmail()
            ." bezahlt.";        
   }       
}

// Adapter zur unpassenden Klasse
class PaypalAdapter implements Bezahlbar {
   private $paypal;
   
   public function __construct(Paypal $paypal){
     $this->paypal = $paypal;  
   } 
    
   public function zahlen(){
     return $this->paypal->bezahlen();  
   }
   public function setBetrag($betrag){
     $this->paypal->setSumme($betrag);   
   }
   public function setEmpfaenger($empfaenger){
     $this->paypal->setEmail($empfaenger);    
   } 
   public function getBetrag(){
     return $this->paypal->getSumme();  
   }
   public function getEmpfaenger(){
     return $this->paypal->getEmail();  
   }       
}

// Klient
class Auftrag {
   private $zahlungweise;
   
   public function setZahlungsweise(Bezahlbar $zahlungsweise){
     $this->zahlungsweise = $zahlungsweise;    
   }
   public function getZahlungsweise(){
      return $this->zahlungsweise;   
   }
   
   public function ausfuehren(){
     return "Auftrag verarbeiten..."
            .$this->zahlungsweise->zahlen()
            ."...und beenden";    
   }   
}

// Test
$kreditkarte = new Kreditkarte(100, "Webshop");
$paypal = new Paypal(100, "bezahlen@webshop.biz");
$paypalAdapter = new PaypalAdapter($paypal);
$auftrag = new Auftrag;
$auftrag->setZahlungsweise($paypalAdapter);
echo $auftrag->ausfuehren();
?>
</body>
</html>
