<!doctype html public "-//W3C//DTD HTML 4.0 //EN">
<html>
<head>
       <title>Entwurfsmuster in der Datenschicht</title>
</head>
<body>
<?php
function __autoload($class) {
 $classFile = $class .".php";
 if (file_exists($classFile)){
   require_once $classFile;
 }
 else {
   echo "<p>Ein Fehler ist aufgetreten.</p>";
 }
}

// DB-Einstellungen laden
require_once("db_properties.inc.php");
// DB-Einstellungen global verfgbar machen
$registry = Registry::getInstance();
$registry->setProperty("user", $user);
$registry->setProperty("password", $password);
$registry->setProperty("database", $database);
$registry->setProperty("host", $host);
// Datenbank-Verbindung erstellen ...
$dbMysql = new DB_Mysql($registry->getProperty("user"),
                    $registry->getProperty("password"),
					$registry->getProperty("database"),
					$registry->getProperty("host"));
try {
 $con = $dbMysql->connect();
 // ... und global verfgbar machen ...
 $registry->setProperty("con", $con);
}
catch (DBException $e){
 echo $e->getMessage();
}
?>
<h1>Active Record</h1>
<?php
try {
 $Kunde = new KundeActiveRecord("Frau", "Elvira", "Huelzeman", "Berlin");
 echo "Testausgabe: ";
 $KundeNr = $Kunde->insert();
 if (! empty($KundeNr)){
  $elvira = KundeActiveRecord::find($KundeNr);
  echo "DB-Abruf: "; echo $elvira;
  $Kunde->setK_NACHNAME("Hlzemann");
  $Kunde->update();
  echo "Nach Aktualisierung: "; echo $Kunde;
  echo $Kunde->anmelden();
  $KundeRows = $Kunde->delete();
  echo $KundeRows." gelscht.<br/>";
 }
}
catch(InsufficientDataException $e) {
 echo $e->getMessage();
}
?>
<h1>Data Mapper</h1>
<?php
try {
 $KundeMapper = new KundeMapper;
 // Kunde-Objekt erstellen...
 $Kunde = new Kunde("Frau", "Elvira", "Huelzeman", "Berlin");
 echo "Testausgabe: "; echo $Kunde;
 // ...und speichern...
 $KundeNr = $KundeMapper->insert($Kunde);
 if (! empty($KundeNr)){
  // ...wiederfinden...
  $elvira = $KundeMapper->findByK_NR($KundeNr);
  echo "DB-Abruf: "; echo $elvira;
  // ...aktualisieren...
  $elvira->setK_NACHNAME("Hlzemann");
  $KundeMapper->update($elvira);
  // ...wiederfinden...
  $elvira = $KundeMapper->findByK_NR($KundeNr);
  echo "Nach Aktualisierung: "; echo $elvira;
  // ...verwenden...
  echo $elvira->anmelden();
  // ...und lschen.
  $KundeRows = $KundeMapper->delete($elvira->getK_NR());
  echo $KundeRows." gelscht.<br/>";
 }
 // Kundenliste abrufen
 $KundeListe = $KundeMapper->findByK_STADT('Berlin');
 echo "<pre>";
 print_r($KundeListe);
 echo "</pre>";
}
catch(InsufficientDataException $e) {
 echo $e->getMessage();
}
?>
<h1>Table Data Gateway</h1>
<?php
try {
 // KundeTDG-Objekt erstellen...
 $KundeGW = new KundeTableGateway();
 // ...speichern...
 $KundeNr = $KundeGW->insert("Frau", "Elvira", "Huelzeman");
 if (! empty($KundeNr)){
   // ...finden...
   $elvira = $KundeGW->findByK_NR($KundeNr);
   echo "Testausgabe Abruf: "; echo $elvira;
   // ...und aktualisieren...
   $KundeGW->update($KundeNr, "Frau", "Elvira", "Hlzemann");
   $elvira = $KundeGW->findByK_NR($KundeNr);
   echo "Nach Aktualisierung: "; echo $elvira;
  // ...verwenden...
  echo $elvira->anmelden();
  // ...und lschen.
  $KundeRows = $KundeGW->delete($elvira->getK_NR());
  echo $KundeRows." gelscht.<br/>";
  // Kundeenliste abrufen
  $KundeListe = $KundeGW->findByK_STADT('Berlin');
  echo "<pre>";
  print_r($KundeListe);
  echo "</pre>";
 }
}
catch(InsufficientDataException $e) {
 echo $e->getMessage();
}
?>
<h1>Row Data Gateway</h1>
<?php
try {
 // KundeGW-Objekt erstellen...
 $KundeGW = new KundeGateway("Frau", "Elvira", "Huelzeman");
 // ...speichern...
 $KundeNr = $KundeGW->insert();
 if (! empty($KundeNr)){
   // ...finden...
   $KundeF = new KundeFinder();
   $elvira = new KundeRDG($KundeF->findByK_NR($KundeNr));
   echo "Testausgabe Abruf: "; echo $elvira;
   // ...und aktualisieren...
   $KundeGW->setK_NACHNAME("Hlzemann");
   $KundeGW->update();
   $elvira = new KundeRDG($KundeF->findByK_NR($KundeNr));
   echo "Nach Aktualisierung: "; echo $elvira;
  // ...verwenden...
  echo $elvira->anmelden();
  // ...und lschen.
  $KundeRows = $KundeGW->delete($elvira->getK_NR());
  echo $KundeRows." gelscht.<br/>";
  // Kundeenliste abrufen
  $KundeListe = $KundeF->findByK_STADT('Berlin');
  echo "<pre>";
  print_r($KundeListe);
  echo "</pre>";
 }
}
catch(InsufficientDataException $e) {
 echo $e->getMessage();
}
?>
</body>
</html>
